package com.tiptimes.ctrl;
import com.tiptimes.model.Answer;
import com.tiptimes.model.Questionnaire;
import com.tiptimes.model.Record;
import com.tiptimes.model.Review;
import com.tiptimes.service.QuestionnaireService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping({"/questionnaire"})
public class QuestionnaireCtrl {
    @Autowired
    private QuestionnaireService questionnaireService;

    public QuestionnaireCtrl() {
    }

    /**
     * 数据上报
     * @param questionnaire 上报数据
     * @return
     */
    @RequestMapping({"/save"})
    @ResponseBody
    public Map<String, Object> save(@RequestBody Questionnaire questionnaire){
        int result;
        //1.通过上报人和问卷id查询上报记录id
        Long recordId=this.questionnaireService.selectRecordId(questionnaire.getId(),questionnaire.getCreateId());
        //2.若recordId为空去添加上报记录，并返回自增id
        if(recordId==null) {
            Record record = new Record(questionnaire.getId(),questionnaire.getQuestionnaireName(),
                    0,questionnaire.getWritePeople(),questionnaire.getPhoneNumber(),questionnaire.getCreateName(),
                    new Date(),questionnaire.getCreateId());
            recordId=this.questionnaireService.insertRecord(record);
        }
        //3.根据上报记录id删除原上报数据
            this.questionnaireService.delAnswer(recordId);
        //4.新增新的上报数据
            List<Answer> answerList=questionnaire.getAnswersList();
            result=this.questionnaireService.insertAnswer(answerList,recordId);
        //5.根据类型判断是否修改上报状态
        if(questionnaire.getType()==1) {//上报
            //修改数据上报状态
            Record r = new Record();
            r.setId(recordId);
            r.setProcessStatus(1);
            result=this.questionnaireService.updateRecord(r);
        }
        Map<String, Object> map = new HashMap();
        if(result>0) {
            map.put("result", true);
            map.put("msg", "操作成功");
        } else {
            map.put("result", false);
            map.put("msg", "操作失败");
        }
            return map;
        }

    /**
     * 审核页面操作
     * @param record 驳回
     * @return
     */
    @RequestMapping({"/checkReject"})
    @ResponseBody
    public Map<String, Object> checkReject(@RequestBody Record record){
        if(record.getReviews()!=null) {
            //1.通过记录id删除原有备注
            this.questionnaireService.delView(record.getReviews().get(0).getRecordId());
            //2.添加新的备注
            this.questionnaireService.insertReview(record.getReviews(), record.getReviews().get(0).getRecordId());
        }
        int result=this.questionnaireService.updateRecord(record);
        Map<String, Object> map = new HashMap();
        if(result>0) {
            map.put("result", true);
            map.put("msg", "操作成功");
        } else {
            map.put("result", false);
            map.put("msg", "操作失败");
        }
        return map;
    }

    /**
     * 根据上报id查看上报数据详情
     * @param recordId 记录id
     * @return
     */
    @RequestMapping({"/selectDetails"})
    @ResponseBody
    public Map<String, Object> selectDetails(Long recordId){
        //1.根据记录id查询上报数据详情
        List<Answer>answerList=this.questionnaireService.selectAnswerByRecordId(recordId);
        //2.根据记录id查询审核备注详情
        List<Review> reviews=this.questionnaireService.selectReviewByRecordId(recordId);
        Map<String, Object> map = new HashMap();
        map.put("result", true);
        map.put("msg", "");
        Map<String, Object> data = new HashMap();
        data.put("answerList",answerList);
        if(reviews.size()>0) {
          data.put("reviews", reviews);
        }
        //3.根据记录id查询状态
        Record record= this.questionnaireService.selectById(recordId);
        data.put("createBy",record.getCreateBy());
        data.put("phoneNumber",record.getPhoneNumber());
        if(record.getProcessStatus()==2) {
          data.put("reason", record.getReason());
        }
        map.put("data",data);
        return map;
    }

    /**
     * 保存备注
     * @param review 备注
     * @return
     */
    @RequestMapping({"/review"})
    @ResponseBody
    public Map<String, Object> review(@RequestBody List<Review> review){
        Map<String, Object> map = new HashMap();
        if(review==null||review.size()==0) {
            map.put("result", false);
            map.put("msg", "不存在需要保存的备注");
            return map;
        }
        int result;
        //1.通过记录id删除原有备注
        this.questionnaireService.delView(review.get(0).getRecordId());
        //2.添加新的备注
        result=this.questionnaireService.insertReview(review,review.get(0).getRecordId());
        if(result>0) {
            map.put("result", true);
            map.put("msg", "操作成功");
        } else {
            map.put("result", false);
            map.put("msg", "操作失败");
        }
        return map;
    }



    /**
     * 按条件查询上报记录
     * @param record 筛选条件
     * @return
     */
    @RequestMapping({"/selectRecordList"})
    @ResponseBody
    public Map<String, Object> selectRecordList(Record record){
        List<Record> recordList= this.questionnaireService.selectRecordList(record);
        Map<String, Object> map = new HashMap();
        Map<String, Object> data = new HashMap();
        map.put("result", true);
        map.put("msg", "");
        data.put("recordList",recordList);
        map.put("data",data);
        return map;
    }
}

